Task: MTurk WikiMovies
=======================
Description: Closed-domain QA dataset asking MTurk-derived questions about movies, answerable from Wikipedia. From Li et al. '16. 

Link: https://arxiv.org/abs/1611.09823

Tags: #MTurkWikiMovies, #All, #QA

